Crate billing_kit

Crate billing_kit 

Billing primitives built on decimal-money.

Re-exports decimal_money::CurrencyAmount and decimal_money::Currency and provides Price — a net/gross/tax helper that mirrors ecom-core::Money::percentage_of and the promo/insurance math in ecom-http (crates/ecom-http/tests/integration_test.rs).

Structs

CurrencyAmount
A monetary amount with a currency.
Decimal
Decimal represents a 128 bit representation of a fixed-precision decimal number. The finite set of values of type Decimal are of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.
Price
A net price plus a percentage tax rate (e.g. VAT 20%).

Enums

Currency
Represents a supported currency.
MoneyError
Errors that can occur in money operations.
PriceError
Errors for Price construction.